Struct ethers_solc::output::sources::VersionedSourceFile
source · pub struct VersionedSourceFile {
pub source_file: SourceFile,
pub version: Version,
}Expand description
A SourceFile and the compiler version used to compile it
Fields
source_file: SourceFileversion: VersionTrait Implementations
sourceimpl Clone for VersionedSourceFile
impl Clone for VersionedSourceFile
sourcefn clone(&self) -> VersionedSourceFile
fn clone(&self) -> VersionedSourceFile
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for VersionedSourceFile
impl Debug for VersionedSourceFile
sourceimpl<'de> Deserialize<'de> for VersionedSourceFile
impl<'de> Deserialize<'de> for VersionedSourceFile
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where __D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<VersionedSourceFile> for VersionedSourceFile
impl PartialEq<VersionedSourceFile> for VersionedSourceFile
sourcefn eq(&self, other: &VersionedSourceFile) -> bool
fn eq(&self, other: &VersionedSourceFile) -> bool
This method tests for
self and other values to be equal, and is used
by ==.