Struct ethers_solc::sourcemap::SourceElement
source · pub struct SourceElement {
pub offset: usize,
pub length: usize,
pub index: Option<u32>,
pub jump: Jump,
pub modifier_depth: usize,
}Expand description
Represents a single element in the source map A solidity source map entry takes the following form
before 0.6.0 s:l:f:j
after 0.6.0 s:l:f:j:m
Where s is the byte-offset to the start of the range in the source file, l is the length of the source range in bytes and f is the source index.
Fields
offset: usizeThe byte-offset to the start of the range in the source file
length: usizeThe length of the source range in bytes
index: Option<u32>the source index
Note: In the case of instructions that are not associated with any particular source file,
the source mapping assigns an integer identifier of -1. This may happen for bytecode
sections stemming from compiler-generated inline assembly statements.
This case is represented as a None value
jump: JumpJump instruction
modifier_depth: usize“modifier depth”. This depth is increased whenever the placeholder statement (_) is entered in a modifier and decreased when it is left again.