Struct ethers_solc::ArtifactId
source · pub struct ArtifactId {
pub path: PathBuf,
pub name: String,
pub source: PathBuf,
pub version: Version,
}Expand description
Represents unique artifact metadata for identifying artifacts on output
Fields
path: PathBufartifact cache path
name: Stringsource: PathBufOriginal source file path
version: Versionsolc version that produced this artifact
Implementations
sourceimpl ArtifactId
impl ArtifactId
sourcepub fn slash_paths(&mut self)
pub fn slash_paths(&mut self)
Converts any \\ separators in the path to /
sourcepub fn with_slashed_paths(self) -> Self
pub fn with_slashed_paths(self) -> Self
Convenience function fo Self::slash_paths()
sourcepub fn slug(&self) -> String
pub fn slug(&self) -> String
Returns a <filename>:<name> slug that identifies an artifact
Note: This identifier is not necessarily unique. If two contracts have the same name, they will share the same slug. For a unique identifier see ArtifactId::identifier.
sourcepub fn identifier(&self) -> String
pub fn identifier(&self) -> String
Returns a <source path>:<name> slug that uniquely identifies an artifact
sourcepub fn slug_versioned(&self) -> String
pub fn slug_versioned(&self) -> String
Returns a <filename><version>:<name> slug that identifies an artifact