Struct ethers_solc::ConfigurableArtifacts
source · pub struct ConfigurableArtifacts {
pub additional_values: ExtraOutputValues,
pub additional_files: ExtraOutputFiles,
/* private fields */
}Expand description
An Artifact implementation that can be configured to include additional content and emit
additional files
Creates a single json artifact with
{
"abi": [],
"bytecode": {...},
"deployedBytecode": {...},
"methodIdentifiers": {...},
// additional values
}
Fields
additional_values: ExtraOutputValuesA set of additional values to include in the contract’s artifact file
additional_files: ExtraOutputFilesA set of values that should be written to a separate file
Implementations
sourceimpl ConfigurableArtifacts
impl ConfigurableArtifacts
pub fn new( extra_values: impl IntoIterator<Item = ContractOutputSelection>, extra_files: impl IntoIterator<Item = ContractOutputSelection> ) -> Self
sourcepub fn output_selection(&self) -> Vec<ContractOutputSelection> ⓘ
pub fn output_selection(&self) -> Vec<ContractOutputSelection> ⓘ
Returns the output selection corresponding to this configuration