Struct ethers_solc::ExtraOutputValues
source · pub struct ExtraOutputValues {Show 16 fields
pub ast: bool,
pub userdoc: bool,
pub devdoc: bool,
pub method_identifiers: bool,
pub storage_layout: bool,
pub assembly: bool,
pub gas_estimates: bool,
pub compact_format: bool,
pub metadata: bool,
pub ir: bool,
pub ir_optimized: bool,
pub ewasm: bool,
pub function_debug_data: bool,
pub generated_sources: bool,
pub source_map: bool,
pub opcodes: bool,
/* private fields */
}Expand description
Determines the additional values to include in the contract’s artifact file
Fields
ast: booluserdoc: booldevdoc: boolmethod_identifiers: boolstorage_layout: boolassembly: boolgas_estimates: boolcompact_format: boolmetadata: boolir: boolir_optimized: boolewasm: boolfunction_debug_data: boolgenerated_sources: boolsource_map: boolopcodes: boolImplementations
sourceimpl ExtraOutputValues
impl ExtraOutputValues
sourcepub fn from_output_selection(
settings: impl IntoIterator<Item = ContractOutputSelection>
) -> Self
pub fn from_output_selection( settings: impl IntoIterator<Item = ContractOutputSelection> ) -> Self
Sets the values based on a set of ContractOutputSelection